@@ -4,8 +4,8 @@
 
 ;; Author: Michał Krzywkowski <k.michal@zoho.com>
 ;; Keywords: data, tools
-;; Package-Version: 0.2.0
-;; Package-Revision: v0.2.0-0-gf9a34cf11a41
+;; Package-Version: 20251228.1347
+;; Package-Revision: d97efb2c2701
 ;; Homepage: https://github.com/mkcms/gpx-mode
 ;; Package-Requires: ((emacs "27.1"))
 
@@ -135,7 +135,7 @@ of the GPX file.")
   (rx line-start (one-or-more space)
       (group-n 1
         "Track #" (group-n 2 (one-or-more digit))
-        (one-or-more any)
+        (one-or-more not-newline)
         "Segment #" (group-n 3 (one-or-more digit))))
   "A regexp to match track/segment dump in human-readable GPX buffer.
 After inserting human-readable GPX file in the buffer, this
